@@ -1,13 +1,14 @@
-from pathos.multiprocessing import ProcessingPool as Pool
 from functools import partial
 from multiprocessing import cpu_count
+from typing import Callable
+
+from pathos.multiprocessing import ProcessingPool as Pool
 
 from parallely.base import ParalellyFunction
 from parallely.utils import prepare_arguments
 
 
 class ParallelFunction(ParalellyFunction):
-
     def _execute_once(self, *args, **kwargs):
         return self._func(*args, **kwargs)
 
@@ -15,11 +16,10 @@ class ParallelFunction(ParalellyFunction):
         return [self._func(*args, **kwargs) for args, kwargs in zip(arg_list, kwarg_list)]
 
     def _chunks(self, l, n):
-        """ Yield successive n-sized chunks from l.
-        """
+        """Yield successive n-sized chunks from l."""
         l = list(l)
         for i in range(0, len(l), n):
-            yield l[i:i + n]
+            yield l[i : i + n]
 
     def map(self, *args, **kwargs):
         args, kwargs = prepare_arguments(args, kwargs)
@@ -27,13 +27,23 @@ class ParallelFunction(ParalellyFunction):
 
         with Pool(pool_size) as pool:
             results = []
-            for chunk in pool.map(self._serial_func, self._chunks(args, pool_size), self._chunks(kwargs, pool_size)):
+            for chunk in pool.map(
+                self._serial_func,
+                self._chunks(args, pool_size),
+                self._chunks(kwargs, pool_size),
+            ):
                 results += chunk
 
         return results
 
 
-def parallel(func=None, max_workers=cpu_count()):
+def parallel(func: Callable = None, max_workers: int = cpu_count()) -> ParallelFunction:
+    """
+
+    :param func:
+    :param max_workers:
+    :return:
+    """
     if func is None:
         return partial(parallel, max_workers=max_workers)
 
