@@ -1,16 +1,17 @@
 from concurrent.futures import ThreadPoolExecutor
 from functools import partial
 from multiprocessing import cpu_count
+from typing import Any, Callable, List
 
 from parallely.base import ParalellyFunction
 from parallely.utils import prepare_arguments
 
-class ThreadedFunction(ParalellyFunction):
 
-    def _execute_once(self, *args, **kwargs):
+class ThreadedFunction(ParalellyFunction):
+    def _execute_once(self, *args, **kwargs) -> Any:
         return self._func(*args, **kwargs)
 
-    def map(self, *args, **kwargs):
+    def map(self, *args, **kwargs) -> List[Any]:
         args, kwargs = prepare_arguments(args, kwargs)
         pool_size = min(self._max_workers, len(args))
 
@@ -20,7 +21,13 @@ class ThreadedFunction(ParalellyFunction):
         return [future.result() for future in futures]
 
 
-def threaded(func=None, max_workers=cpu_count() * 10):
+def threaded(func: Callable = None, max_workers: int = cpu_count() * 10) -> ThreadedFunction:
+    """
+
+    :param func:
+    :param max_workers:
+    :return:
+    """
     if func is None:
         return partial(threaded, max_workers=max_workers)
 
